"""
MERIT: Monitoring, Evaluation, Reporting, Inspection, Testing

A comprehensive framework for evaluating and testing AI systems,
particularly those powered by Large Language Models (LLMs).
"""

__version__ = "0.1.16"
